==> library1.4.1.tar.bz2: library/rez_off.php <==
<?php
  ///////////////////////////////////////////////////
  //Отключить резервирование
  //2010 (C)
  //Карпухин Павел
  ///////////////////////////////////////////////////

  require_once "utils/chlang_osn.php";

  $title = $TEXT['aut-title-info'];

  require_once "config.php";
  require_once "utils/functions.php";
  require_once "utils/top.php";

  if($result2['administrator'] == 0) {puterror2($result2['skin'],$TEXT['error-loginform2']); require_once "utils/bottom.php"; exit();}

  if(empty($_GET['book_id'])) {puterror2($result2['skin'],$TEXT['error-book5']); require_once "utils/bottom.php"; exit();}
  if(strlen($_GET['book_id'])>255) {puterror2($result2['skin'],$TEXT['error-book6']); require_once "utils/bottom.php"; exit();}
  $_GET['book_id'] = rep($_GET['book_id']);

  //*************************************
  //Информация для лога
   $query_body = "SELECT `book_name` FROM tbl_book WHERE `book_id` = '".$_GET['book_id']."'";
     $result_body = mysqli_query($dbcnx,$query_body);
     if(!$result_body) {puterror2($result2['skin'],$TEXT['error-tbl3']); require_once "utils/bottom.php"; exit();}
      $result_body_book = mysqli_fetch_array($result_body);

  $ip = $_SERVER['REMOTE_ADDR'];
  $doing = $TEXT['log-book9'];
  $what = $result_body_book['book_name'];
  $who = $result2['familiya']." ".$result2['name'];
  //*************************************

  $query = "UPDATE `tbl_book` SET `zakazano`='0', `data_zakaza`='1970-01-01', `user_id_zak`='0' WHERE `book_id`='".$_GET['book_id']."' ";
  if(mysqli_query($dbcnx,$query))
  {
   $query_log = "INSERT INTO tbl_logs ( `log_id` , `data` , `ip` , `who` , `doing` , `what` ) VALUES ( NULL , NOW() , '$ip' , '$who' , '$doing' , '$what')";
     if(mysqli_query($dbcnx,$query_log))
      {
      echo "<html><head>
          <meta HTTP-EQUIV='Refresh' CONTENT='0; URL=info.php?book_id=".$_GET['book_id']."' />
          </head></html>";
      } else {puterror($result2['skin'],$TEXT['error-log']); require_once "utils/bottom.php"; exit();}
  } else {puterror2($result2['skin'],$TEXT['error-tbl3']); require_once "utils/bottom.php"; exit();}
require_once "utils/bottom.php";
?>

==> library1.19.1.tar.bz2: library/rez_off.php <==
<?php
  ///////////////////////////////////////////////////
  //Отключить резервирование
  //2010 (C)
  //Карпухин Павел
  ///////////////////////////////////////////////////

  require_once "utils/chlang_osn.php";

  $title = $TEXT['aut-title-info'];

  require_once "config.php";
  require_once "utils/functions.php";
  require_once "utils/top.php";

  if($result2['administrator'] == 0 && $result2['user'] == 0) {puterror2($result2['skin'],$TEXT['error-loginform2']); require_once "utils/bottom.php"; exit();}

  if(empty($_GET['book_id'])) {puterror2($result2['skin'],$TEXT['error-book5']); require_once "utils/bottom.php"; exit();}
  if(strlen($_GET['book_id'])>255) {puterror2($result2['skin'],$TEXT['error-book6']); require_once "utils/bottom.php"; exit();}
  $_GET['book_id'] = rep($_GET['book_id']);

  //*************************************
  //Информация для лога
   $query_body = "SELECT `book_name` FROM tbl_book WHERE `book_id` = '".$_GET['book_id']."'";
     $result_body = mysqli_query($dbcnx,$query_body);
     if(!$result_body) {puterror2($result2['skin'],$TEXT['error-tbl3']); require_once "utils/bottom.php"; exit();}
      $result_body_book = mysqli_fetch_array($result_body);

  $ip = $_SERVER['REMOTE_ADDR'];
  $doing = $TEXT['log-book9'];
  $what = $result_body_book['book_name'].", ".$TEXT['log-id']." ".$_GET['book_id'];
  $who = $result2['familiya']." ".$result2['name'];
  //*************************************

  $query = "UPDATE `tbl_book` SET `zakazano`='0', `data_zakaza`='1970-01-01', `user_id_zak`='0', `user_id`='0' WHERE `book_id`='".$_GET['book_id']."' ";
  if(mysqli_query($dbcnx,$query))
  {
   $query_log = "INSERT INTO tbl_logs ( `log_id` , `data` , `ip` , `who` , `doing` , `what` ) VALUES ( NULL , NOW() , '$ip' , '$who' , '$doing' , '$what')";
     if(mysqli_query($dbcnx,$query_log))
      {
      echo "<html><head>
          <meta HTTP-EQUIV='Refresh' CONTENT='0; URL=info.php?book_id=".$_GET['book_id']."' />
          </head></html>";
      } else {puterror2($result2['skin'],$TEXT['error-log']); require_once "utils/bottom.php"; exit();}
  } else {puterror2($result2['skin'],$TEXT['error-tbl3']); require_once "utils/bottom.php"; exit();}
require_once "utils/bottom.php";
?>
